Module buffer_pool

Module buffer_pool 

Functions

consume_buffer_total_bytes
Total number of bytes allocated across all ConsumeBuffer objects. We’re not able to track this with better granularity because the ConsumeBuffers may be resized, and they don’t know their pools.
pool_active_count
Number of objects currently active and in-use.
pool_idle_bytes
Memory footprint of objects currently in the pool.
pool_idle_count
Number of objects available for reuse in the pool.