Functions
- consume_
buffer_ total_ bytes - Total number of bytes allocated across all
ConsumeBufferobjects. We’re not able to track this with better granularity because the ConsumeBuffers may be resized, and they don’t know their pools. - pool_
active_ count - Number of objects currently active and in-use.
- pool_
idle_ bytes - Memory footprint of objects currently in the pool.
- pool_
idle_ count - Number of objects available for reuse in the pool.